// 
//  ManagedPuzzle.m
//  Demine
//
//  Created by Michael Heyeck on 4/23/10.
//  Copyright 2010 Fair Oaks Labs, Inc.. All rights reserved.
//

#import "Puzzle.h"
#import "HighScore.h"
#import "ManagedPuzzle.h"


@implementation ManagedPuzzle 

@dynamic w;
@dynamic h;
@dynamic nMines;
@dynamic nUncovered;
@dynamic nFlagged;
@dynamic elapsedTime;
@dynamic status;
@dynamic cells;
@dynamic createDate;
@dynamic scrollX;
@dynamic scrollY;


- (void)awakeFromInsert
{
	[super awakeFromInsert];
	[self setPrimitiveValue:[NSDate date] forKey:@"createDate"];
}


- (void)willSave
{
	[super willSave];
	
	// Don't bother unless we've won
	if ([self.status integerValue] != PuzzleStatusSolved) return;
	
	// This puzzle's HS key
	NSString* key = [NSString stringWithFormat:@"%@.%@.%@",self.w,self.h,self.nMines];

	// Find the HS record (if any) for this key
	NSError* err;
	NSFetchRequest* request = [[NSFetchRequest alloc] init];
	request.entity = [NSEntityDescription entityForName:@"HighScore" inManagedObjectContext:self.managedObjectContext];
	request.predicate = [NSPredicate predicateWithFormat:@"key = %@",key];
	NSArray* highScores = [self.managedObjectContext executeFetchRequest:request error:&err];
	[request release];

	// Get a HS record
	HighScore* hs;
	if ([highScores count])
	{
		hs = [highScores objectAtIndex:0];

		if ([self.elapsedTime doubleValue] < [hs.best doubleValue])
		{
			hs.best = self.elapsedTime;
		}
	}
	else
	{
		hs = [NSEntityDescription insertNewObjectForEntityForName:@"HighScore" inManagedObjectContext:self.managedObjectContext];

		hs.width	= self.w;
		hs.height	= self.h;
		hs.mines	= self.nMines;
		hs.key		= key;
		hs.best		= self.elapsedTime;
	}
}

@end
