//
//  NewPuzzle.m
//  Demine
//
//  Created by Michael Heyeck on 4/25/10.
//  Copyright 2010 Fair Oaks Labs, Inc.. All rights reserved.
//

#import "UIButton+Glossy.h"
#import "Store.h"
#import "CustomPuzzle.h"
#import "NewPuzzle.h"


@interface NewPuzzle ()

- (void)dismiss;

@end


@implementation NewPuzzle

@synthesize makeXX;
@synthesize make10;
@synthesize make40;
@synthesize make99;


// The parent's designated initializer. Overriden to call the new DI.
- (id)initWithNibName:(NSString*)nibNameOrNil bundle:(NSBundle*)nibBundleOrNil
{
	return [self initWithNibName:nibNameOrNil bundle:nibBundleOrNil target:nil];
}


// The new designated initializer.
- (id)initWithNibName:(NSString*)nibNameOrNil bundle:(NSBundle*)nibBundleOrNil target:(RootViewController*)aTarget;
{
    if (self = [super initWithNibName:nibNameOrNil bundle:nibBundleOrNil])
	{
		if (aTarget)
		{
			target = aTarget;
		}
		else
		{
			[self release];
			return nil;
		}
    }
    return self;
}


/*
// Implement loadView to create a view hierarchy programmatically, without using a nib.
- (void)loadView {
}
*/


// Implement viewDidLoad to do additional setup after loading the view, typically from a nib.
- (void)viewDidLoad
{
    [super viewDidLoad];
	
	// Weird hack - I don't want to talk about it
	self.view.backgroundColor = [UIColor groupTableViewBackgroundColor];

	// Buttons
	if (![make10 backgroundImageForState:UIControlStateNormal])
	{
		[make10 setBackgroundToGlossyRectOfColor:[UIColor colorWithRed:0.05 green:0.6 blue:0.05 alpha:1] withBorder:YES forState:UIControlStateNormal];
	}
	if (![make40 backgroundImageForState:UIControlStateNormal])
	{
		[make40 setBackgroundToGlossyRectOfColor:[UIColor colorWithRed:0.05 green:0.05 blue:0.6 alpha:1] withBorder:YES forState:UIControlStateNormal];
	}
	if (![make99 backgroundImageForState:UIControlStateNormal])
	{
		[make99 setBackgroundToGlossyRectOfColor:[UIColor colorWithRed:0.6 green:0.05 blue:0.05 alpha:1] withBorder:YES forState:UIControlStateNormal];
	}
	if (![makeXX backgroundImageForState:UIControlStateNormal])
	{
		[makeXX setBackgroundToGlossyRectOfColor:[UIColor purpleColor] withBorder:YES forState:UIControlStateNormal];
	}
	
	// Buttons
	self.navigationItem.leftBarButtonItem = [[[UIBarButtonItem alloc] initWithBarButtonSystemItem:UIBarButtonSystemItemCancel target:self action:@selector(dismiss)] autorelease];

	// Titles
	self.title = @"New Puzzle";
	self.navigationItem.backBarButtonItem = [[[UIBarButtonItem alloc] initWithTitle:@"New" style:UIBarButtonItemStyleBordered target:nil action:nil] autorelease];
}


/*
// Override to allow orientations other than the default portrait orientation.
- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation {
    // Return YES for supported orientations
    return (interfaceOrientation == UIInterfaceOrientationPortrait);
}
*/

- (void)didReceiveMemoryWarning {
	// Releases the view if it doesn't have a superview.
    [super didReceiveMemoryWarning];
	
	// Release any cached data, images, etc that aren't in use.
}

- (void)viewDidUnload {
	// Release any retained subviews of the main view.
	// e.g. self.myOutlet = nil;
}


- (IBAction)makePuzzle:(id)sender
{
	// Make puzzle (or defer to custom screen)
	id p = nil;
	if (sender == make10)
	{
		p = [target addPuzzleWithWidth:8 height:8 mines:10];
	}
	else if (sender == make40)
	{
		p = [target addPuzzleWithWidth:16 height:16 mines:40];
	}
	else if (sender == make99)
	{
		if (![[NSUserDefaults standardUserDefaults] integerForKey:@"enableAllPuzzles"])
		{
			NSString* msg = @"We must ask you to pay an upgrade fee before unlocking the expert and custom puzzles.  Do you wish to proceed to the store?";
			UIAlertView* av = [[UIAlertView alloc] initWithTitle:nil
														 message:msg
														delegate:self
											   cancelButtonTitle:@"Cancel"
											   otherButtonTitles:@"Visit Store",nil];
			[av show];
			[av release];
			return;
		}
		p = [target addPuzzleWithWidth:30 height:16 mines:99];
	}
	else
	{
		if (![[NSUserDefaults standardUserDefaults] integerForKey:@"enableAllPuzzles"])
		{
			NSString* msg = @"We must ask you to pay an upgrade fee before unlocking the expert and custom puzzles.  Do you wish to proceed to the store?";
			UIAlertView* av = [[UIAlertView alloc] initWithTitle:nil
														 message:msg
														delegate:self
											   cancelButtonTitle:@"Cancel"
											   otherButtonTitles:@"Visit Store",nil];
			[av show];
			[av release];
			return;
		}
		CustomPuzzle* cp = [[[CustomPuzzle alloc] initWithNibName:@"CustomPuzzle" bundle:nil target:target] autorelease];
		[self.navigationController pushViewController:cp animated:YES];
	}
	if (p) [self dismiss];
}


- (void)dealloc
{
	[makeXX release];
	[make10 release];
	[make40 release];
	[make99 release];
    [super dealloc];
}

#pragma mark Alert view delegate methods

- (void)alertView:(UIAlertView*)av clickedButtonAtIndex:(NSInteger)buttonIndex
{
	if (buttonIndex != av.cancelButtonIndex)
	{
		Store* store = [[[Store alloc] initWithNibName:@"Store" bundle:nil] autorelease];
		UINavigationController* nc = [[[UINavigationController alloc] initWithRootViewController:store] autorelease];
		[self.navigationController presentModalViewController:nc animated:YES];
	}
	
}

#pragma mark Extension methods

- (void)dismiss
{
	[self.navigationController.parentViewController dismissModalViewControllerAnimated:YES];
}

@end
